% Same as em, but initializes mixture parameters to random values instead of
% requiring them as inputs. Requires an input parameter K that specifies the
% desired number of mixture components. Also returns the initial values.

function [p, m, sigma, pkn, niter, p0, m0, sigma0] = emi(x, K, tol, maxiter)

if nargin < 3
    tol = [];
end

if nargin < 4
    maxiter = [];
end

% Centroid of all the data points
m0 = colmean(x')';

% Standard deviation in each 

sigma0 = colstd(x')';

oK = ones(1, K);

% K initial means somewhere within the cloud of data points
m0 = m0 * oK + sigma0 * randn(1, K);

% K standard deviations
sigma0 = mean(sigma0) * oK;

% Note: we can probably do better for both m and sigma by estimating
% expected distances between K points in D dimensions

% K initial mixing probabilities
p0 = oK / K;

% Run the EM algorithm
[p, m, sigma, pkn, niter] = em(x, p0, m0, sigma0, tol, maxiter);