% Evaluates a multidimensional, isotropic Gaussian with mean m and
% standard deviation sigma at the data points in the columns of x

function g = gauss(x, m, sigma, normalize)

D = size(x, 1);

if nargin < 2
    m = [];
end

if nargin < 3
    sigma = [];
end

if nargin < 4
    normalize = [];
end

if isempty(m)
    m = zeros(D, 1);
end

if isempty(sigma)
    sigma = 1;
end

if isempty(normalize)
    normalize = 0;
end

m = m(:);

if min(size(x)) == 1
    x = x(:)';
end

if length(m) ~= D
    error('Mean and data points must have the same number of dimensions')
end

if ~all(size(m) == 1)
    m = m * ones(1, size(x, 2));
end

g = exp(- colsum((x - m) .^ 2) / (sigma^2) / 2) / (sqrt(2 * pi) * sigma) ^ D;